picu - Python ctypes-based Bindings for ICU
===========================================

This is a Python wrapper that provides access to some features in the `ICU (International Components for Unicode) library`_.

Features
--------

- load multiple versions of ICU (containing different Unicode database versions) in the same process
- `Unicode character database properties exposed by ICU`_ such as character name, age, script and most 
- Pythonic interface to `ICU regular expressions`_
- Pythonic interface to `ICU UnicodeSet`_, which provides efficient storage and operations of sets containing Unicode code points


.. _ICU (International Components for Unicode) library: http://site.icu-project.org/
.. _ICU UnicodeSet: http://userguide.icu-project.org/strings/unicodeset
.. _ICU Regular Expressions: http://userguide.icu-project.org/strings/regexp
.. _Unicode character database properties exposed by ICU: http://userguide.icu-project.org/strings/properties
